#################################################################################################
#   A file which kills pWindow in WarpFX_GUI when exiting, it sets buttons at Mission Start     #
#   and it determines warp degradation over here.                                               #
#                                                                                               #
#   by USS Sovereign                                                                            #
#                                                                                               #
#   License: It's a part of CWS Mod. You know the drill, code borrowing needs to be credited... #
#                                                                                               #
#   Note: If you've uninstalled CWS it's safe to delete this file. It won't give you any        #
#   trouble if you haven't but it's recommended. However if you've uninstalled NanoFX you'll    #
#   notice that this file is giving you BSOD. It's cause it's importing a file which most       #
#   likely was deleted in the uninstall process.                                                #
#################################################################################################


##### Imports
import App
import Foundation
import MissionLib
from Custom.Autoload.LoadNanoFX import *


##### Trigger
class SovFixTrigger(Foundation.TriggerDef):
	def __init__(self, name, eventKey, dict = {}):
		Foundation.TriggerDef.__init__(self, name, eventKey, dict)

	def __call__(self, pObject, pEvent, dict = {}):
                pGame = App.Game_GetCurrentGame()
                pEpisode = pGame.GetCurrentEpisode()
                pMission = pEpisode.GetCurrentMission()

                ##### If the user is in QBR Mode using this has lethal consequences
                if pMission.GetScript() == "Custom.QuickBattleGame.QuickBattle":
                    return
                
                try:
                    
                    import Custom.NanoFXv2.WarpFX.WarpFX_GUI
                    Custom.NanoFXv2.WarpFX.WarpFX_GUI.exiting(None, None)
                    
                except:
                    
                    print "CWS 2.0: Why am I still here on your computer?! Delete me... my name is: SovNFX2Fix.py & pyc"
                    return

SovFixTrigger('SovFixTrigger', App.ET_QUIT, dict = { 'modes': [ mode ] } )


##### Trigger
class SovButtonTrigger(Foundation.TriggerDef):
	def __init__(self, name, eventKey, dict = {}):
		Foundation.TriggerDef.__init__(self, name, eventKey, dict)

	def __call__(self, pObject, pEvent, dict = {}):
                try:
                    
                    import Custom.NanoFXv2.WarpFX.WarpFX_GUI
                    Custom.NanoFXv2.WarpFX.WarpFX_GUI.SetupButtons()
                    
                except:
                    
                    print "CWS 2.0: Why am I still here on your computer?! Delete me... my name is: SovNFX2Fix.py & pyc"
                    return

SovButtonTrigger('SovButtonTrigger', App.ET_MISSION_START, dict = { 'modes': [ mode ] } )


##### Trigger
class SovWarpDegradingTrigger(Foundation.TriggerDef):
	def __init__(self, name, eventKey, dict = {}):
		Foundation.TriggerDef.__init__(self, name, eventKey, dict)

	def __call__(self, pObject, pEvent, dict = {}):
                WarpDegrading()    
                

SovWarpDegradingTrigger('SovWarpDegradingTrigger', App.ET_ENTERED_SET, dict = { 'modes': [ mode ] } )


##### Warp degradation of the players warp engines. 
def WarpDegrading():
        WarpCheck = DoWarpingCheck()

        if WarpCheck == 'Skip':
            return
    
        CurrentWarp = GetCurrentWarpSpeed()
        
        if CurrentWarp == 'Skip':
            return

        CruisingWarpSpeed = GetCruisingWarpSpeed()

        if CruisingWarpSpeed == 'Skip':
            return

        if CurrentWarp <= CruisingWarpSpeed:
            return

        TimeSpentInWarp = GetTimeSpentInWarp()

        if TimeSpentInWarp == 'Skip':
            return

        Degradation = (CurrentWarp - CruisingWarpSpeed) * TimeSpentInWarp

        Degradation = Degradation / 100
        
        SetDegradation(Degradation)


##### Warp Degradation Check
def SetDegradation(Percentage):
        pPlayer = MissionLib.GetPlayer()
        pWarp = pPlayer.GetWarpEngineSubsystem()

        if pWarp:
            DegradingInProgress(pPlayer, pWarp, Percentage)


##### Warp engines degrading
def DegradingInProgress(pShip, pSubsystem, fPercentage, bIsChild = 0):
        if (bIsChild != 0) or (pSubsystem.GetNumChildSubsystems() == 0):
                fStats = pSubsystem.GetConditionPercentage()
                PreCalculation = fStats - fPercentage
                if (PreCalculation <= 0.01):
                    pSubsystem.SetConditionPercentage(0.01)

                else:
                    pSubsystem.SetConditionPercentage(fStats - fPercentage)

	for i in range(pSubsystem.GetNumChildSubsystems()):
		pChild = pSubsystem.GetChildSubsystem(i)

		if (pChild != None):
			DegradingInProgress(pShip, pChild, fPercentage, 1)


##### See if the player ship is actually warping
def DoWarpingCheck():
        pPlayer = MissionLib.GetPlayer()
        pWarp = pPlayer.GetWarpEngineSubsystem()
        if not pPlayer or not pWarp or pWarp.GetWarpState() != pWarp.WES_WARPING:
            return 'Skip'
                        	

##### Grab current warp speed of the ship
def GetCurrentWarpSpeed():
        try:
            
            import Custom.NanoFXv2.WarpFX.WarpFX_GUI

            fWarpSpeed = Custom.NanoFXv2.WarpFX.WarpFX_GUI.GetWarpSpeed()

            return fWarpSpeed

        except:
            
            return 'Skip'
        
##### Grab safe cruising speed of the ship
def GetCruisingWarpSpeed():
        try:
            import Custom.NanoFXv2.WarpFX.WarpFX_GUI

            fCruiseSpeed = Custom.NanoFXv2.WarpFX.WarpFX_GUI.ReturnCruiseSpeed()

            return fCruiseSpeed

        except:
            
            return 'Skip'


##### Grab time spent in Warp
def GetTimeSpentInWarp():
        try:
            import Custom.NanoFXv2.WarpFX.WarpFX

            fTime = Custom.NanoFXv2.WarpFX.WarpFX.ReturnWarpTime()

            return fTime

        except:

            return 'Skip'


##### Trigger
class SovWarpResetTrigger(Foundation.TriggerDef):
	def __init__(self, name, eventKey, dict = {}):
		Foundation.TriggerDef.__init__(self, name, eventKey, dict)

	def __call__(self, pObject, pEvent, dict = {}):
                try:
                    
                    import Custom.NanoFXv2.WarpFX.WarpFX_GUI
                    Custom.NanoFXv2.WarpFX.WarpFX_GUI.ResetWarpSpeed()
                    
                except:
                    
                    return

SovWarpResetTrigger('SovWarpResetTrigger', App.ET_SET_PLAYER, dict = { 'modes': [ mode ] } )


